#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.analysis_interfaces.analysis_local_entity import AnalysisLocalEntity
from pycatia.system_interfaces.collection import Collection
from pycatia.types.general import cat_variant


class AnalysisLocalEntities(Collection):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.Collection
                |                     AnalysisLocalEntities
                | 
                | The collection of local analysis entities.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object, child_object=AnalysisLocalEntity)
        self.analysis_local_entities = com_object

    def add(self, i_type: str) -> AnalysisLocalEntity:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func Add(CATBSTR iType) As AnalysisLocalEntity
                | 
                |     Creates a new analysis local entity and adds it to the analysis entities
                |     collection.
                |     This collection may be extracted from an analysis entity.The Analysis local
                |     entity will be created on the Analysis entity.
                | 
                |     Parameters:
                | 
                |         iType
                |             The type of the entity to create. 
                | 
                |     Returns:
                |         The created analysis entity 
                |     Example:
                | 
                |           This example create ThisAnalysisEntity in the analysisEntities
                |           collection 
                | 
                |          The entity to create is supposed to be a pressure defined in a load
                |          set.
                | 
                |          
                | 
                |          Dim analysisEntities As CATIAAnalysisLocalEntities
                |          Dim ThisAnalysisEntity As AnalysisEntity
                |          Set ThisAnalysisEntity = analysisEntities.Add("SAMShellLocal")

        :param str i_type:
        :rtype: AnalysisLocalEntity
        """
        return AnalysisLocalEntity(self.analysis_local_entities.Add(i_type))

    def item(self, i_index: cat_variant) -> AnalysisLocalEntity:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func Item(CATVariant iIndex) As AnalysisLocalEntity
                | 
                |     Returns an analysis entity using its index or its name from the analysis
                |     entities collection.
                | 
                |     Parameters:
                | 
                |         iIndex
                |             The index or the name of the analysis entity to retrieve from the
                |             collection of analysis entities. As a numerics, this index is the rank of the
                |             analysis entity in the collection. The index of the first analysis entity in
                |             the collection is 1, and the index of the last analysis entity is Count. As a
                |             string, it is the name you assigned to the analysis entity using the
                |             
                | 
                |         AnyObject.Name property or when creating it using the Add method.
                |         
                |     Returns:
                |         The retrieved analysis entity

        :param cat_variant i_index:
        :rtype: AnalysisLocalEntity
        """
        return AnalysisLocalEntity(self.analysis_local_entities.Item(i_index))

    def remove(self, i_index: cat_variant) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub Remove(CATVariant iIndex)
                | 
                |     Returns an analysis local entity.
                | 
                |     Parameters:
                | 
                |         iIndex
                |             The index or the name of the analysis entity to retrieve from the
                |             collection of analysis entities. As a numerics, this index is the rank of the
                |             analysis entity in the collection. The index of the first analysis entity in
                |             the collection is 1, and the index of the last analysis entity is Count. As a
                |             string, it is the name you assigned to the analysis entity using the
                |             
                | 
                |         AnyObject.Name property or when creating it using the Add method.

        :param cat_variant i_index:
        :rtype: None
        """
        return self.analysis_local_entities.Remove(i_index)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'remove'
        # # vba_code = """
        # # Public Function remove(analysis_local_entities)
        # #     Dim iIndex (2)
        # #     analysis_local_entities.Remove iIndex
        # #     remove = iIndex
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def __repr__(self):
        return f'AnalysisLocalEntities(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.in_interfaces.document import Document
from pycatia.system_interfaces.any_object import AnyObject


class ProcessDocument(Document):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     InfInterfaces.Document
                |                         ProcessDocument
                | 
                | This interface is used to access the PPRDocument and to add a new
                | library.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.process_document = com_object

    @property
    def dnb_3d_state_position_management(self) -> AnyObject:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property DNB3DStatePositionManagement() As CATBaseDispatch (Read
                | Only)
                | 
                |     Retrieves the interface which manages the 3D state
                |     positions.
                | 
                |     Returns:
                |         The DNBIA3DStatePositionManagement corresponding to the current Process
                |         document.

        :rtype: AnyObject
        """

        return AnyObject(self.process_document.DNB3DStatePositionManagement)

    @property
    def ppr_document(self) -> AnyObject:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property PPRDocument() As CATBaseDispatch (Read Only)
                | 
                |     Retrieves the interface which manages the PPRDocument.
                | 
                |     Returns:
                |         The PPRDocument corresponding to the current Process document.

        :rtype: AnyObject
        """

        return AnyObject(self.process_document.PPRDocument)

    def add_library(self, i_file_name: str) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub AddLibrary(CATBSTR iFileName)
                | 
                |     Adds a new library to the current Process document.
                | 
                |     Parameters:
                | 
                |         iFileName
                |             The name of the library to be added.

        :param str i_file_name:
        :rtype: None
        """
        return self.process_document.AddLibrary(i_file_name)

    def __repr__(self):
        return f'ProcessDocument(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-06-11 12:40:47.360445

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from typing import TYPE_CHECKING

from pycatia.system_interfaces.any_object import AnyObject
from pycatia.types.general import cat_variant

if TYPE_CHECKING:
    from pycatia.drafting_interfaces.drawing_view import DrawingView
    from pycatia.drafting_interfaces.drawing_sheet import DrawingSheet


class DrawingComponent(AnyObject):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     DrawingComponent
                | 
                | Represents a drawing component instance (ditto) in a drawing
                | view.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.drawing_component = com_object

    @property
    def angle(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
                | o Property Angle() As double
                | 
                |     Returns or sets the angle of the drawing component instance. The angle is
                |     given in the axis system of the drawing view The angle is measured in radians
                |     and is counted counterclockwise.
                | 
                |     Example:
                |         This example sets the angle of the MyComponent drawing component
                |         instance to 90 degrees clockwise. You first need to compute the angle in
                |         radians and set the minus sign to indicate the rotation is
                |         clockwise.
                | 
                |          PI = 3.1415926535
                |          Angle90Clockwise = -PI/2
                |          MyComponent.Angle = Angle90Clockwise

        :rtype: float
        """

        return self.drawing_component.Angle

    @angle.setter
    def angle(self, value: float):
        """
        :param float value:
        """

        self.drawing_component.Angle = value

    @property
    def comp_ref(self) -> 'DrawingView':
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
                | o Property CompRef() As DrawingView (Read Only)
                | 
                |     Returns the component reference of this drawing component instance. this is
                |     a CATIADrawingView
                | 
                |     Example:
                |         This example gets the drawing component reference of the MyComponent
                |         drawing component instance.
                | 
                |          Dim ComponentRef As DrawingView
                |          Set ComponentRef = MyComponent.CompRef

        :rtype: DrawingView
        """
        from pycatia.drafting_interfaces.drawing_view import DrawingView
        return DrawingView(self.drawing_component.CompRef)

    @property
    def scale2(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
                | o Property Scale2() As double
                | 
                |     Returns or sets the scale of the drawing component instance (Workaround for
                |     VBA keyword).
                | 
                |     Example:
                |         This example sets the scale of the MyComponent drawing component
                |         instance to 0.5.
                | 
                |          MyComponent.Scale2 = 0.5

        :rtype: float
        """

        return self.drawing_component.Scale2

    @scale2.setter
    def scale2(self, value: float):
        """
        :param float value:
        """

        self.drawing_component.Scale2 = value

    @property
    def x(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
                | o Property x() As double
                | 
                |     Returns or sets the x coordinate of the drawing component instance
                |     position. It is expressed with respect to the view coordinate system. This
                |     coordinate, like any length, is measured in millimeters.
                | 
                |     Example:
                |         This example sets the x coordinate of the position of the MyComponent
                |         drawing component instance to 5 inches. You need first to convert the 5 inches
                |         into millimeters.
                | 
                |          NewXCoordinate = 5*25.4
                |          MyComponent.x =  NewXCoordinate

        :rtype: float
        """

        return self.drawing_component.x

    @x.setter
    def x(self, value: float):
        """
        :param float value:
        """

        self.drawing_component.x = value

    @property
    def y(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
                | o Property y() As double
                | 
                |     Returns or sets the y coordinate of the drawing component instance
                |     position. It is expressed with respect to the view coordinate system. This
                |     coordinate, like any length, is measured in millimeters.
                | 
                |     Example:
                |         This example sets the y coordinate of the position of the MyComponent
                |         drawing component instance to 5 inches. You need first to convert the 5 inches
                |         into millimeters.
                | 
                |          NewYCoordinate = 5*25.4
                |          MyComponent.y =  NewYCoordinate

        :rtype: float
        """

        return self.drawing_component.y

    @y.setter
    def y(self, value: float):
        """
        :param float value:
        """

        self.drawing_component.y = value

    def explode(self) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
                | o Sub Explode()
                | 
                |     Explodes the drawing component instance (every sub elements of the drawing
                |     component are created). Note: The drawing component is not removed by Explode
                |     method
                | 
                |     Example:
                |         This example Explodes the MyComponent drawing component instance and
                |         removes it.
                | 
                |          MyComponent.Explode
                |          Set MySelection = CATIA.ActiveDocument.Selection
                |          MySelection.clear
                |          MySelection.add MyComponent
                |          MySelection.delete

        :rtype: None
        """
        return self.drawing_component.Explode()

    def explode_and_select(self) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
                | o Sub ExplodeAndSelect()
                | 
                |     Explodes the drawing component instance (every sub elements of the drawing
                |     component are created) and put created sub elements in selection
                |     set.
                | 
                |     Example:
                |         This example Explodes the MyComponent drawing component
                |         instance.
                | 
                |          MyComponent.ExplodeAndSelect

        :rtype: None
        """
        return self.drawing_component.ExplodeAndSelect()

    def expose_comp_ref(self) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
                | o Sub ExposeCompRef()
                | 
                |     Exposes the component reference of this drawing component instance in a new
                |     detail sheet.
                | 
                |     Example:
                |         This example exposes the component reference of the MyComponent drawing
                |         component instance in a new detail sheet.
                | 
                |          MyComponent.ExposeCompRef

        :rtype: None
        """
        return self.drawing_component.ExposeCompRef()

    def expose_comp_ref_in_sheet(self, i_sheet: 'DrawingSheet') -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
                | o Sub ExposeCompRefInSheet(DrawingSheet iSheet)
                | 
                |     Exposes the component reference of this drawing component instance in a
                |     specific detail sheet.
                | 
                |     Parameters:
                | 
                |         iSheet
                |             The drawing sheet where the reference component has to be exposed.
                |             This sheet has to be a detail sheet, if not the component reference will be
                |             placed in a new detail sheet.
                | 
                |             Example:
                |                 This example exposes the component reference of the MyComponent
                |                 drawing component instance in the MyDetailSheet drawing
                |                 sheet.
                | 
                |                  MyComponent.ExposeCompRefInSheet
                |                  MyDetailSheet

        :param DrawingSheet i_sheet:
        :rtype: None
        """
        return self.drawing_component.ExposeCompRefInSheet(i_sheet.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'expose_comp_ref_in_sheet'
        # # vba_code = """
        # # Public Function expose_comp_ref_in_sheet(drawing_component)
        # #     Dim iSheet (2)
        # #     drawing_component.ExposeCompRefInSheet iSheet
        # #     expose_comp_ref_in_sheet = iSheet
        # # End Function
        # # """

        # # system_service = self.application.system_service
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def flip(self) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
                | o Sub Flip()
                | 
                |     Flips the drawing component instance around X axis To flip around Y axis
                |     you have to flip the component around X and to add a rotation of 180
                |     degrees.
                | 
                |     Example:
                |         This example Flips the MyComponent drawing component
                |         instance.
                | 
                |          MyComponent.Flip

        :rtype: None
        """
        return self.drawing_component.Flip()

    def get_flip(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
                | o Func GetFlip() As boolean
                | 
                |     Returns the flip state of a drawing component instance around X
                |     axis.
                | 
                |     Example:
                |         This example Get the flip info of the MyComponent drawing component
                |         instance.
                | 
                |          IsFlipped = MyComponent.GetFlip

        :rtype: bool
        """
        return self.drawing_component.GetFlip()

    def get_matrix(self, io_matrix: tuple) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
                | o Sub GetMatrix(CATSafeArrayVariant ioMatrix)
                | 
                |     Gets the matrix of the drawing component instance. This matrix enables you
                |     to define the position (index 4 and 5 of the matrix) and the scale, the angle
                |     and the flip (index 0,1,2 and 3) of the drawing component instance at the same
                |     time.
                | 
                |     Parameters:
                | 
                |         ioMatrix[0]
                |             The 1st coordinate of the first vector 
                |         ioMatrix[1]
                |             The 2nd coordinate of the first vector 
                |         ioMatrix[2]
                |             The 1st coordinate of the second vector 
                |         ioMatrix[3]
                |             The 2nd coordinate of the second vector 
                |         ioMatrix[4]
                |             The x value of the translation vector 
                |         ioMatrix[5]
                |             The y value of the translation vector

        :param tuple io_matrix:
        :rtype: None
        """
        return self.drawing_component.GetMatrix(io_matrix)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'get_matrix'
        # # vba_code = """
        # # Public Function get_matrix(drawing_component)
        # #     Dim ioMatrix (2)
        # #     drawing_component.GetMatrix ioMatrix
        # #     get_matrix = ioMatrix
        # # End Function
        # # """

        # # system_service = self.application.system_service
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def get_modifiable_object(self, i_index: cat_variant) -> AnyObject:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
                | o Func GetModifiableObject(CATVariant iIndex) As AnyObject
                | 
                |     Gets a modifiable object by index or name in this drawing component
                |     instance.
                | 
                |     Example:
                |         This example Gets the first modifiable object in the MyComponent
                |         drawing component instance.
                | 
                |          Object = MyComponent.GetModifiableObject(1)

        :param cat_variant i_index:
        :rtype: AnyObject
        """
        return AnyObject(self.drawing_component.GetModifiableObject(i_index))

    def get_modifiable_objects_count(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
                | o Func GetModifiableObjectsCount() As long
                | 
                |     Gets the number of modifiable objects in this drawing component
                |     instance.
                | 
                |     Example:
                |         This example Gets the number of modifiable objects in MyComponent
                |         drawing component instance.
                | 
                |          Count = MyComponent.GetModifiableObjectsCount

        :rtype: int
        """
        return self.drawing_component.GetModifiableObjectsCount()

    def set_matrix(self, i_matrix: tuple) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
                | o Sub SetMatrix(CATSafeArrayVariant iMatrix)
                | 
                |     Sets the matrix of the drawing component instance. This matrix enables you
                |     to define the position (index 4 and 5 of the matrix) and the scale, the angle
                |     and the flip (index 0,1,2 and 3) of the drawing component instance at the same
                |     time.
                | 
                |     Parameters:
                | 
                |         ioMatrix[0]
                |             The 1st coordinate of the first vector 
                |         ioMatrix[1]
                |             The 2nd coordinate of the first vector 
                |         ioMatrix[2]
                |             The 1st coordinate of the second vector 
                |         ioMatrix[3]
                |             The 2nd coordinate of the second vector 
                |         ioMatrix[4]
                |             The x value of the translation vector 
                |         ioMatrix[5]
                |             The y value of the translation vector

        :param tuple i_matrix:
        :rtype: None
        """
        return self.drawing_component.SetMatrix(i_matrix)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_matrix'
        # # vba_code = """
        # # Public Function set_matrix(drawing_component)
        # #     Dim iMatrix (2)
        # #     drawing_component.SetMatrix iMatrix
        # #     set_matrix = iMatrix
        # # End Function
        # # """

        # # system_service = self.application.system_service
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def __repr__(self):
        return f'DrawingComponent(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.dnb_fastener_interfaces.curve_fastener import CurveFastener
from pycatia.dnb_fastener_interfaces.fastener_group import FastenerGroup
from pycatia.dnb_fastener_interfaces.point_fastener import PointFastener
from pycatia.system_interfaces.any_object import AnyObject


class DnbFastenerManagement(AnyObject):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     DNBFastenerManagement
                | 
                | Valid fastener process types and its fastening context *
                | The valid known values for process types for fasteners and value for its
                | fastening context
                | 
                |     Point fasteners fastening context
                |     sealant point
                |     1
                |     spot weld
                |     2
                |     stud weld
                |     2
                |     Glue Drop
                |     1
                |     Rivet
                |     2
                |     Screw
                |     2
                |     clinch
                |     2
                |     Drill
                |     2
                |     adhesive point
                |     1
                |     stud
                |     2 Curve fasteners
                |     adhesive Curve
                |     1
                |     arc weld
                |     2
                |     sealant curve
                |     1
                |     glue bead
                |     1
                |     adhesive
                |     1
                |     sealant
                |     1
                |     spot glue
                |     1
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.dnb_fastener_management = com_object

    def create_curve_fastener(
            self,
            i_name: str,
            i_parent_group_body: FastenerGroup,
            i_list_of_joining_parts: tuple,
            i_process_type: str,
            i_fastening_context: int,
            i_design_points_positions: tuple,
            i_feature_cgr_path: str,
            o_curve_fastener: CurveFastener
    ) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub CreateCurveFastener(CATBSTR iName,
                | FastenerGroup iParentGroupBody,
                | CATSafeArrayVariant iListOfJoiningParts,
                | CATBSTR iProcessType,
                | short iFasteningContext,
                | CATSafeArrayVariant iDesignPointsPositions,
                | CATBSTR iFeatureCGRPath,
                | CurveFastener oCurveFastener)
                | 
                |     Creates a curve fastener in the V5 .. only for flat file
                |     scenario.
                | 
                |     Parameters:
                | 
                |         in
                |             CATBSTR iName Name of the feature to be created.. a unique value
                |             has to be provided. 
                |         inout
                |             DELMIAFastenerGroup iParentGroupBody Parent under which fastener to
                |             be created In case of no parent provided, fastener would be created under top
                |             fastener group(assembly joint(s)) automatically. 
                |         in
                |             CATSafeArrayVariant iListOfJoiningParts List of joining parts for
                |             fastener In case, the parent assembly joint already has joining part
                |             information empty list can be provided, 
                |         in
                |             CATBSTR iProcessType Process type for fastener : refer known values on top section of
                |             file. any custom value other than known values can be provided
                |         in
                |             short iFasteningContext fastening contex : refer known values on top section of file for
                |             a process type For custom fastener type.. value can be 1 or greater. if any other value
                |             provided default would be set to 2.
                |         in
                |             CATSafeArrayVariant iDesignPointsPositions Design position for
                |             curve fastener Multiple support points can be provided in a sequence in the
                |             array in the order of "XYZYPR" for each point .. YPR values should be in
                |             Degree. if fastener has n points , then size of array should be exactly of 6n
                |             now assign values for first point's poisition in XYZYPR format at location 0-5
                |             .. next point's 6-11... next 12-17... 18-23... 6(n-1)-(6n-1)
                |             
                |         in
                |             CATBSTR iFeatureCGRPath Representation for curve fastener Value
                |             should be complete file path 
                |         out
                |             DELMIACurveFastener oCurveFastener Created curve fastener *
                |             
                | 
                |     Example:
                |         Set myObject = CATIA.GetItem("DNBFastenerManagement")
                |         myObject.CreateCurveFastener "Curve Fastener.1", ParentGroupObj,JoinPartArray,"arc weld",2, DesignPos, FeatureRepPath, oCurveFast

        :param str i_name:
        :param FastenerGroup i_parent_group_body:
        :param tuple i_list_of_joining_parts:
        :param str i_process_type:
        :param int i_fastening_context:
        :param tuple i_design_points_positions:
        :param str i_feature_cgr_path:
        :param CurveFastener o_curve_fastener:
        :rtype: None
        """
        return self.dnb_fastener_management.CreateCurveFastener(
            i_name,
            i_parent_group_body.com_object,
            i_list_of_joining_parts,
            i_process_type,
            i_fastening_context,
            i_design_points_positions,
            i_feature_cgr_path,
            o_curve_fastener.com_object
        )
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'create_curve_fastener'
        # # vba_code = """
        # # Public Function create_curve_fastener(dnb_fastener_management)
        # #     Dim iName (2)
        # #     dnb_fastener_management.CreateCurveFastener iName
        # #     create_curve_fastener = iName
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def create_fastener_group(
            self,
            i_name: str,
            i_parent_group_body: FastenerGroup,
            i_list_of_joining_parts: tuple,
            o_fastener_group: FastenerGroup
    ) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub CreateFastenerGroup(CATBSTR iName,
                | FastenerGroup iParentGroupBody,
                | CATSafeArrayVariant iListOfJoiningParts,
                | FastenerGroup oFastenerGroup)
                | 
                |     Creates a fastener group in the V5 .. only for flat file
                |     scenario.
                | 
                |     Parameters:
                | 
                |         in
                |             CATBSTR iName Name of the feature to be created.. a unique value
                |             has to be provided. 
                |         inout
                |             DELMIAFastenerGroup iParentGroupBody Parent under which fastener
                |             group to be created In case of no parent provided, fastener group would be
                |             created under top fastener group(assembly joint(s)) automatically.
                |             
                |         in
                |             CATSafeArrayVariant iListOfJoiningParts List of joining parts for
                |             fastener If the List has joining parts .. an assembly joint is created If list
                |             has no part .. a normal fastener group is created 
                |         out
                |             DELMIAFastenerGroup oFastenerGroup Created fastener group *
                |             
                | 
                |     Example:
                |         Set myObject = CATIA.GetItem("DNBFastenerManagement")
                |         myObject.CreateFastenerGroup "Assembly Joint.1", ParentGroupObj,JoinPartArray,oFastenerGroup

        :param str i_name:
        :param FastenerGroup i_parent_group_body:
        :param tuple i_list_of_joining_parts:
        :param FastenerGroup o_fastener_group:
        :rtype: None
        """
        return self.dnb_fastener_management.CreateFastenerGroup(
            i_name,
            i_parent_group_body.com_object,
            i_list_of_joining_parts,
            o_fastener_group.com_object
        )
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'create_fastener_group'
        # # vba_code = """
        # # Public Function create_fastener_group(dnb_fastener_management)
        # #     Dim iName (2)
        # #     dnb_fastener_management.CreateFastenerGroup iName
        # #     create_fastener_group = iName
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def create_point_fastener(
            self,
            i_name: str,
            i_parent_group_body: FastenerGroup,
            i_list_of_joining_parts: tuple,
            i_process_type: str,
            i_fastening_context: int,
            i_design_position: tuple,
            o_point_fastener: PointFastener
    ) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub CreatePointFastener(CATBSTR iName,
                | FastenerGroup iParentGroupBody,
                | CATSafeArrayVariant iListOfJoiningParts,
                | CATBSTR iProcessType,
                | short iFasteningContext,
                | CATSafeArrayVariant iDesignPosition,
                | PointFastener oPointFastener)
                | 
                |     Creates a point fastener in the V5 .. only for flat file
                |     scenario.
                | 
                |     Parameters:
                | 
                |         in
                |             CATBSTR iName Name of the feature to be created.. a unique value
                |             has to be provided. 
                |         inout
                |             DELMIAFastenerGroup iParentGroupBody Parent under which fastener to
                |             be created In case of no parent provided, fastener would be created under top
                |             fastener group(assembly joint(s)) automatically. 
                |         in
                |             CATSafeArrayVariant iListOfJoiningParts List of joining parts for
                |             fastener In case, the parent assembly joint already has joining part
                |             information empty list can be provided, 
                |         in
                |             CATBSTR iProcessType Process type for fastener : refer known values on top section of
                |             file. any custom value other than known values can be provided
                |         in
                |             short iFasteningContext fastening contex : refer known values on top section of file
                |             for a process type For custom fastener type.. value can be 1 or greater. if any other
                |             value provided default would be set to 2.
                |         in
                |             CATSafeArrayVariant iDesignPointsPositions Design position for
                |             point fastener in XYZYPR format .... YPR values should be in Degree. array
                |             should be exactly of size of six array should contains values on index from 0-5
                |             in a sequence order of XYZYPR format. 
                |         out
                |             DELMIAPointFastener oPointFastener Created point fastener *
                |             
                | 
                |     Example:
                |         Set myObject = CATIA.GetItem("DNBFastenerManagement")
                |         myObject.CreatePointFastener "Point Fastener.1", ParentGroupObj,JoinPartArray,"spot weld",2, DesignPos, oPointFastener

        :param str i_name:
        :param FastenerGroup i_parent_group_body:
        :param tuple i_list_of_joining_parts:
        :param str i_process_type:
        :param int i_fastening_context:
        :param tuple i_design_position:
        :param PointFastener o_point_fastener:
        :rtype: None
        """
        return self.dnb_fastener_management.CreatePointFastener(
            i_name,
            i_parent_group_body.com_object,
            i_list_of_joining_parts,
            i_process_type,
            i_fastening_context,
            i_design_position,
            o_point_fastener.com_object
        )
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'create_point_fastener'
        # # vba_code = """
        # # Public Function create_point_fastener(dnb_fastener_management)
        # #     Dim iName (2)
        # #     dnb_fastener_management.CreatePointFastener iName
        # #     create_point_fastener = iName
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def __repr__(self):
        return f'DnbFastenerManagement(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-06-11 12:40:47.360445

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.system_interfaces.any_object import AnyObject


class DrawingDimLine(AnyObject):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     DrawingDimLine
                | 
                | Manages dimension line of a dimension in drawing view.
                | 
                | This interface is obtained from DrawingDimension.GetDimLine
                | method.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.drawing_dim_line = com_object

    @property
    def color(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
                | o Property Color() As long
                | 
                |     Returns or sets color of dimension line.
                | 
                |     Example:
                |         This example retrieves color of dimension line MyDimLine drawing
                |         dimension.
                | 
                |          oColorDimLine = MyDimLine.Color

        :rtype: int
        """

        return self.drawing_dim_line.Color

    @color.setter
    def color(self, value: int):
        """
        :param int value:
        """

        self.drawing_dim_line.Color = value

    @property
    def dim_line_graph_rep(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
                | o Property DimLineGraphRep() As CatDimLineGraphRep
                | 
                |     Returns or graphic representation of dimension line.
                | 
                |     Example:
                |         This example retrieves graphic representation of dimension line
                |         MyDimLine drawing dimension.
                | 
                |          odimLineGraphRep = MyDimLine.DimLineGraphRep

        :return: enum cat_dim_line_graph_rep
        :rtype: int
        """

        return self.drawing_dim_line.DimLineGraphRep

    @dim_line_graph_rep.setter
    def dim_line_graph_rep(self, value: int):
        """
        :param int value: enum cat_dim_line_graph_rep
        """

        self.drawing_dim_line.DimLineGraphRep = value

    @property
    def dim_line_orientation(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
                | o Property DimLineOrientation() As CatDimOrientation
                | 
                |     Returns or orientation of dimension line.
                | 
                |     Example:
                |         This example retrieves orientation of dimension line MyDimLine drawing
                |         dimension.
                | 
                |          odimLineOrient = MyDimLine.DimLineOrientation

        :return: enum cat_dim_orientation
        :rtype: int
        """

        return self.drawing_dim_line.DimLineOrientation

    @dim_line_orientation.setter
    def dim_line_orientation(self, value: int):
        """
        :param int value: enum cat_dim_orientation
        """

        self.drawing_dim_line.DimLineOrientation = value

    @property
    def dim_line_reference(self):
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
                | o Property DimLineReference() As CatDimReference
                | 
                |     Returns or reference of dimension line.
                | 
                |     Example:
                |         This example retrieves reference of dimension line MyDimLine drawing
                |         dimension.
                | 
                |          odimLineRef = MyDimLine.DimLineReference

        :return: enum cat_dim_reference
        :rtype: int
        """

        return self.drawing_dim_line.DimLineReference

    @dim_line_reference.setter
    def dim_line_reference(self, value: int):
        """
        :param int value: enum cat_dim_reference
        """

        self.drawing_dim_line.DimLineReference = value

    @property
    def dim_line_rep(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
                | o Property DimLineRep() As CatDimLineRep (Read Only)
                | 
                |     Returns or representation of dimension line.
                | 
                |     Example:
                |         This example retrieves representation of dimension line MyDimLine
                |         drawing dimension.
                | 
                |          odimLineRep = MyDimLine.DimLineRep

        :return: enum cat_dim_line_rep
        :rtype: int
        """

        return self.drawing_dim_line.DimLineRep

    @property
    def dim_line_type(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
                | o Property DimLineType() As long (Read Only)
                | 
                |     Returns type of dimension line.
                | 
                |     Example:
                |         This example retrieves type of dimension line MyDimLine drawing
                |         dimension.
                | 
                |          odimLineType = MyDimLine.DimLineType

        :rtype: int
        """

        return self.drawing_dim_line.DimLineType

    @property
    def thickness(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
                | o Property Thickness() As double
                | 
                |     Returns or sets thickness of dimension line.
                | 
                |     Example:
                |         This example retrieves thickness of dimension line MyDimLine drawing
                |         dimension.
                | 
                |          oThickDimLine = MyDimLine.Thickness

        :rtype: float
        """

        return self.drawing_dim_line.Thickness

    @thickness.setter
    def thickness(self, value: float):
        """
        :param float value:
        """

        self.drawing_dim_line.Thickness = value

    def get_dim_line_dir(self, o_dir_x: float, o_dir_y: float) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
                | o Sub GetDimLineDir(double oDirX,
                | double oDirY)
                | 
                |     Returns direction of a dimension line in case of a catDimUserDefined
                |     representation mode. To retrieve the representation mode:
                |     DrawingDimLine.get_DimLineRep.
                | 
                |     Parameters:
                | 
                |         oDirX,oDirY
                |             The components of the direction vector 
                |         Example:
                |             This example retrieves the direction vector of a dimension line
                |             MyDimLine drawing dimension.
                | 
                |              MyDimLine.GetDimLineDir oDirX, oDirY

        :param float o_dir_x:
        :param float o_dir_y:
        :rtype: None
        """
        return self.drawing_dim_line.GetDimLineDir(o_dir_x, o_dir_y)

    def get_geom_info(self, o_geom_infos: tuple) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
                | o Sub GetGeomInfo(CATSafeArrayVariant oGeomInfos)
                | 
                |     Get geometrical information of dimension line.
                | 
                |     Parameters:
                | 
                |         oGeomInfos
                |             geometrical information. 
                |         Example:
                |             This example gets geometrical information of MyDimLine
                |             path.
                | 
                |              MyDimLine.GetGeomInfo(oGeomInfos)

        :param tuple o_geom_infos:
        :rtype: None
        """
        return self.drawing_dim_line.GetGeomInfo(o_geom_infos)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'get_geom_info'
        # # vba_code = """
        # # Public Function get_geom_info(drawing_dim_line)
        # #     Dim oGeomInfos (2)
        # #     drawing_dim_line.GetGeomInfo oGeomInfos
        # #     get_geom_info = oGeomInfos
        # # End Function
        # # """

        # # system_service = self.application.system_service
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def get_symb_color(self, index: int) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
                | o Func GetSymbColor(long Index) As long
                | 
                |     Get symbol color of dimension line.
                | 
                |     Parameters:
                | 
                |         Index
                |             1:first symbol 2:second symbol 3:leader symbol 
                |         oColorSymb
                |             symbol color. 
                |         Example:
                |             This example gets symbol color of MyDimLine path.
                | 
                |              ColorSymb = MyDimLine.GetSymbColor(Index)

        :param int index:
        :rtype: int
        """
        return self.drawing_dim_line.GetSymbColor(index)

    def get_symb_thickness(self, index: int) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
                | o Func GetSymbThickness(long Index) As double
                | 
                |     Get symbol thickness of dimension line.
                | 
                |     Parameters:
                | 
                |         Index
                |             1:first symbol 2:second symbol 3:leader symbol 
                |         oThickSymb
                |             symbol thickness. 
                |         Example:
                |             This example gets symbol thickness of MyDimLine
                |             path.
                | 
                |              ThickSymb = MyDimLine.GetSymbThickness(Index)

        :param int index:
        :rtype: float
        """
        return self.drawing_dim_line.GetSymbThickness(index)

    def get_symb_type(self, index: int) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
                | o Func GetSymbType(long Index) As CatDimSymbols
                | 
                |     Get symbol type of dimension line.
                | 
                |     Parameters:
                | 
                |         Index
                |             1:first symbol 2:second symbol 3:leader symbol 
                |         oTypeSymb
                |             symbol type. 
                |         Example:
                |             This example gets symbol type of MyDimLine path.
                | 
                |              typeSymb = MyDimLine.GetSymbType(Index)

        :param int index:
        :return: enum cat_dim_symbols
        :rtype: int
        """
        return self.drawing_dim_line.GetSymbType(index)

    def set_symb_color(self, index: int, i_color_symb: int) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
                | o Sub SetSymbColor(long Index,
                | long iColorSymb)
                | 
                |     Set symbol color of dimension line.
                | 
                |     Parameters:
                | 
                |         Index
                |             1:first symbol 2:second symbol 3:leader symbol 
                |         oColorSymb
                |             symbol color. 
                |         Example:
                |             This example sets symbol color of MyDimLine path.
                | 
                |              MyDimLine.SetSymbColor(Index, iColorSymb)

        :param int index:
        :param int i_color_symb:
        :rtype: None
        """
        return self.drawing_dim_line.SetSymbColor(index, i_color_symb)

    def set_symb_thickness(self, index: int, i_thick_symb: float) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
                | o Sub SetSymbThickness(long Index,
                | double iThickSymb)
                | 
                |     Set symbol thickness of dimension line.
                | 
                |     Parameters:
                | 
                |         Index
                |             1:first symbol 2:second symbol 3:leader symbol 
                |         oThickSymb
                |             symbol thickness. 
                |         Example:
                |             This example sets symbol thickness of MyDimLine
                |             path.
                | 
                |              MyDimLine.GetSymbThickness(Index, iThickSymb)

        :param int index:
        :param float i_thick_symb:
        :rtype: None
        """
        return self.drawing_dim_line.SetSymbThickness(index, i_thick_symb)

    def set_symb_type(self, index: int, i_symb_type: int) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
                | o Sub SetSymbType(long Index,
                | CatDimSymbols iSymbType)
                | 
                |     Set symbol type of dimension line.
                | 
                |     Parameters:
                | 
                |         Index
                |             1:first symbol 2:second symbol 3:leader symbol 
                |         iSymbType
                |             symbol type. 
                |         Example:
                |             This example sets symbol type of MyDimLine path.
                | 
                |              MyDimLine.SetSymbType(Index, iSymbType)

        :param int index:
        :param int i_symb_type: enum cat_dim_symbols
        :rtype: None
        """
        return self.drawing_dim_line.SetSymbType(index, i_symb_type)

    def __repr__(self):
        return f'DrawingDimLine(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.structure_interfaces.str_member import StrMember
from pycatia.system_interfaces.collection import Collection
from pycatia.types.general import cat_variant


class StrMembers(Collection):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.Collection
                |                     StrMembers
                | 
                | A collection of the Member objects contained in a given Product object of a
                | ProductDocument object.
                | A Product object aggregates zero or one Members collection. This collection is
                | retrieved using the Product.GetTechnologicalObject method of the
                | product.
                | 
                | Example:
                |     The following example retrieves the member collection from the oProduct
                |     Product.
                | 
                |      Dim oMembers as AnyObject
                |      Set oMembers = oProduct.GetTechnologicalObject("StructureMembers")
                |      
                | 
                |     Method Index
                |     Item
                |         Returns a member from its index in the Members collection.
                |         
                |     Remove
                |         Removes a member from the Members collection. 
                | 
                |     Methods
                | 
                | o Func Item(	CATVariant 	iIndex) As StrMember
                | 
                |     Returns a member from its index in the Members collection.
                | 
                |     Parameters:
                | 
                |         iIndex
                |             The index of the member to retrieve in the collection of members.
                |             This index can either be the rank of the member in the collection or the name
                |             you assign to the member. As a numerics, this index is the rank of the member
                |             in the collection. The index of the first member in the collection is 1, and
                |             the index of the last member is Count. As a string, it is the name you assigned
                |             to the member using the 
                | 
                |         AnyObject.Name property 
                |     Returns:
                |         The retrieved member 
                |     Example:
                | 
                |           The following example returns in ThisMember the third
                |           member,
                |          and in ThatMember the member named
                |          Column_1 in the Assembly_1 member collection.
                |          
                | 
                |          Dim ThisMember As Member
                |          Set ThisMember = Assembly_1.Item(3)
                |          Dim ThatMember As Member
                |          Set ThatMember = Assembly.Item("Column_1")
                |          
                | 
                | o Sub Remove(	CATVariant 	iIndex)
                | 
                |     Removes a member from the Members collection.
                | 
                |     Parameters:
                | 
                |         iIndex
                |             The index of the member to remove. This index can either be the
                |             rank of the member in the collection or the name you assigned to the member. As
                |             a numerics, this index is the rank of the member in the collection. The index
                |             of the first member in the collection is 1, and the index of the last member is
                |             Count. As a string, it is the name you assigned to the member using the
                |             
                | 
                |         AnyObject.Name property 
                |     Example:
                | 
                |           The following example removes the sixth member and the member
                |           named
                |          Column_1 from the Assembly_1 member collection.
                |          
                | 
                |          Assembly_1.Remove(6)
                |          Assembly_1.Remove("Column_1")
                |          
                | 
                | Copyright © 1999-2011, Dassault Systèmes. All rights reserved.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object, child_object=StrMember)
        self.str_members = com_object

    def item(self, i_index: cat_variant) -> StrMember:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func Item(CATVariant iIndex) As StrMember
                | 
                |     Returns a member from its index in the Members collection.
                | 
                |     Parameters:
                | 
                |         iIndex
                |             The index of the member to retrieve in the collection of members.
                |             This index can either be the rank of the member in the collection or the name
                |             you assign to the member. As a numerics, this index is the rank of the member
                |             in the collection. The index of the first member in the collection is 1, and
                |             the index of the last member is Count. As a string, it is the name you assigned
                |             to the member using the 
                | 
                |         AnyObject.Name property 
                |     Returns:
                |         The retrieved member 
                |     Example:
                | 
                |           The following example returns in ThisMember the third
                |           member,
                |          and in ThatMember the member named
                |          Column_1 in the Assembly_1 member collection.
                |          
                | 
                |          Dim ThisMember As Member
                |          Set ThisMember = Assembly_1.Item(3)
                |          Dim ThatMember As Member
                |          Set ThatMember = Assembly.Item("Column_1")

        :param cat_variant i_index:
        :rtype: StrMember
        """
        return StrMember(self.str_members.Item(i_index))

    def remove(self, i_index: cat_variant) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub Remove(CATVariant iIndex)
                | 
                |     Removes a member from the Members collection.
                | 
                |     Parameters:
                | 
                |         iIndex
                |             The index of the member to remove. This index can either be the
                |             rank of the member in the collection or the name you assigned to the member. As
                |             a numerics, this index is the rank of the member in the collection. The index
                |             of the first member in the collection is 1, and the index of the last member is
                |             Count. As a string, it is the name you assigned to the member using the
                |             
                | 
                |         AnyObject.Name property 
                |     Example:
                | 
                |           The following example removes the sixth member and the member
                |           named
                |          Column_1 from the Assembly_1 member collection.
                |          
                | 
                |          Assembly_1.Remove(6)
                |          Assembly_1.Remove("Column_1")

        :param cat_variant i_index:
        :rtype: None
        """
        return self.str_members.Remove(i_index)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'remove'
        # # vba_code = """
        # # Public Function remove(str_members)
        # #     Dim iIndex (2)
        # #     str_members.Remove iIndex
        # #     remove = iIndex
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def __repr__(self):
        return f'StrMembers(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.system_interfaces.setting_controller import SettingController


class RRSSettingAtt(SettingController):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     System.SettingController
                |                         RRSSettingAtt
                | 
                | Interface to handle parameters of IGRIP RRS Tools Options Tab page Role: This
                | interface is implemented by a component which represents the controller of
                | IGRIP RRS Tools Options parameter settings.
                | 
                |     Methods to set value of each parameter
                |     Methods to get value of each parameter
                |     Methods to get information on each parameter
                |     Methods to lock/unlock value of each parameter
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.rrs_setting_att = com_object

    def add_new_rrs2_controller_identifier(self, i_controller_identifier: str) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub AddNewRRS2ControllerIdentifier(CATBSTR
                | iControllerIdentifier)
                | 
                |     Adds new controller identifier into the list represented by the
                |     "RRS2ControllerIdentifiers" parameter. If it is already in the list, does
                |     nothing.
                |     Role: Adds new controller identifier to "RRS2ControllerIdentifiers"
                |     list.
                | 
                |     Parameters:
                | 
                |         iControllerIdentifier
                |             Controller Identifier to be added to the list. 
                | 
                |     Returns:
                |         Legal values:
                |         S_OK : on Success
                |         E_FAIL: on Failure

        :param str i_controller_identifier:
        :rtype: None
        """
        return self.rrs_setting_att.AddNewRRS2ControllerIdentifier(i_controller_identifier)

    def get_rcs_data_lib_dir_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetRCSDataLibDirInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the "RCSDATA$LIB"
                |     parameter.
                |     Role:Retrieves the state of the "RCSDATA$LIB" parameter in the current
                |     environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.rrs_setting_att.GetRCSDataLibDirInfo(io_admin_level, io_locked)

    def get_rrs2_connect_downloaders_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetRRS2ConnectDownloadersInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the "RRS2ConnectDownloaders"
                |     parameter.
                |     Role:Retrieves the state of the "RRS2ConnectDownloaders" parameter in the
                |     current environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.rrs_setting_att.GetRRS2ConnectDownloadersInfo(io_admin_level, io_locked)

    def get_rrs2_consistency_cmd_downloaders_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetRRS2ConsistencyCmdDownloadersInfo(CATBSTR
                | ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the "RRS2ConsistencyCmdDownloaders"
                |     parameter.
                |     Role:Retrieves the state of the "RRS2ConsistencyCmdDownloaders" parameter
                |     in the current environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.rrs_setting_att.GetRRS2ConsistencyCmdDownloadersInfo(io_admin_level, io_locked)

    def get_rrs2_controller_identifier_attributes(
            self,
            i_controller_identifier: str,
            o_rrs2_connect_downloader: str,
            o_rrs2_sim_run_downloader: str,
            o_rrs2_consistency_cmd_downloader: str,
            o_rrs2_download_during_connect: bool,
            o_rrs2_download_during_sim_run: bool,
            o_rrs2_update_program_on_download: bool,
            o_rrs2_download_in_part_coordinates: bool
    ) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub GetRRS2ControllerIdentifierAttributes(CATBSTR
                | iControllerIdentifier,
                | CATBSTR oRRS2ConnectDownloader,
                | CATBSTR oRRS2SimRunDownloader,
                | CATBSTR oRRS2ConsistencyCmdDownloader,
                | boolean oRRS2DownloadDuringConnect,
                | boolean oRRS2DownloadDuringSimRun,
                | boolean oRRS2UpdateProgramOnDownload,
                | boolean oRRS2DownloadInPartCoordinates)
                | 
                |     Gets various controller identifier-specific attributes associated with a
                |     given controller identifier.
                |     Role: Gets various attributes associated with a given controller
                |     identifier.
                | 
                |     Parameters:
                | 
                |         iControllerIdentifier
                |             Controller Identifier whose attributes are requested.
                |             
                |         iControllerIdentifier
                |             Controller Identifier whose attributes are requested.
                |
                |     Returns:
                |         Legal values:
                |         S_OK : on Success
                |         E_FAIL: on Failure

        :param str i_controller_identifier:
        :param str o_rrs2_connect_downloader:
        :param str o_rrs2_sim_run_downloader:
        :param str o_rrs2_consistency_cmd_downloader:
        :param bool o_rrs2_download_during_connect:
        :param bool o_rrs2_download_during_sim_run:
        :param bool o_rrs2_update_program_on_download:
        :param bool o_rrs2_download_in_part_coordinates:
        :rtype: None
        """
        return self.rrs_setting_att.GetRRS2ControllerIdentifierAttributes(
            i_controller_identifier,
            o_rrs2_connect_downloader,
            o_rrs2_sim_run_downloader,
            o_rrs2_consistency_cmd_downloader,
            o_rrs2_download_during_connect,
            o_rrs2_download_during_sim_run,
            o_rrs2_update_program_on_download,
            o_rrs2_download_in_part_coordinates
        )
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'get_rrs2_controller_identifier_attributes'
        # # vba_code = """
        # # Public Function get_rrs2_controller_identifier_attributes(rrs_setting_att)
        # #     Dim iControllerIdentifier (2)
        # #     rrs_setting_att.GetRRS2ControllerIdentifierAttributes iControllerIdentifier
        # #     get_rrs2_controller_identifier_attributes = iControllerIdentifier
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def get_rrs2_controller_identifiers_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetRRS2ControllerIdentifiersInfo(CATBSTR
                | ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the "RRS2ControllerIdentifiers"
                |     parameter.
                |     Role:Retrieves the state of the "RRS2ControllerIdentifiers" parameter in
                |     the current environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.rrs_setting_att.GetRRS2ControllerIdentifiersInfo(io_admin_level, io_locked)

    def get_rrs2_delete_auto_download_files_after_xfer_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetRRS2DeleteAutoDownloadFilesAfterXferInfo(CATBSTR
                | ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the
                |     "RRS2DeleteAutoDownloadFilesAfterXfer" parameter.
                |     Role:Retrieves the state of the "RRS2DeleteAutoDownloadFilesAfterXfer"
                |     parameter in the current environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.rrs_setting_att.GetRRS2DeleteAutoDownloadFilesAfterXferInfo(io_admin_level, io_locked)

    def get_rrs2_dflt_controller_identifier_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetRRS2DfltControllerIdentifierInfo(CATBSTR
                | ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the "RRS2DfltControllerIdentifier"
                |     parameter.
                |     Role:Retrieves the state of the "RRS2DfltControllerIdentifier" parameter in
                |     the current environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.rrs_setting_att.GetRRS2DfltControllerIdentifierInfo(io_admin_level, io_locked)

    def get_rrs2_download_during_connect_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetRRS2DownloadDuringConnectInfo(CATBSTR
                | ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the "RRS2DownloadDuringConnect"
                |     parameter.
                |     Role:Retrieves the state of the "RRS2DownloadDuringConnect" parameter in
                |     the current environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.rrs_setting_att.GetRRS2DownloadDuringConnectInfo(io_admin_level, io_locked)

    def get_rrs2_download_during_sim_run_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetRRS2DownloadDuringSimRunInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the "RRS2DownloadDuringSimRun"
                |     parameter.
                |     Role:Retrieves the state of the "RRS2DownloadDuringSimRun" parameter in the
                |     current environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.rrs_setting_att.GetRRS2DownloadDuringSimRunInfo(io_admin_level, io_locked)

    def get_rrs2_download_in_part_coordinates_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetRRS2DownloadInPartCoordinatesInfo(CATBSTR
                | ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the "RRS2DownloadInPartCoordinates"
                |     parameter.
                |     Role:Retrieves the state of the "RRS2DownloadInPartCoordinates" parameter
                |     in the current environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.rrs_setting_att.GetRRS2DownloadInPartCoordinatesInfo(io_admin_level, io_locked)

    def get_rrs2_download_log_file_name_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetRRS2DownloadLogFileNameInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the "RRS2DownloadLogFileName"
                |     parameter.
                |     Role:Retrieves the state of the "RRS2DownloadLogFileName" parameter in the
                |     current environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.rrs_setting_att.GetRRS2DownloadLogFileNameInfo(io_admin_level, io_locked)

    def get_rrs2_free_play_sim_step_size_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetRRS2FreePlaySimStepSizeInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the "RRS2FreePlaySimStepSize"
                |     parameter.
                |     Role:Retrieves the state of the "RRS2FreePlaySimStepSize" parameter in the
                |     current environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.rrs_setting_att.GetRRS2FreePlaySimStepSizeInfo(io_admin_level, io_locked)

    def get_rrs2_main_task_processing_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetRRS2MainTaskProcessingInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the "RRS2MainTaskProcessing"
                |     parameter.
                |     Role:Retrieves the state of the "RRS2MainTaskProcessing" parameter in the
                |     current environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.rrs_setting_att.GetRRS2MainTaskProcessingInfo(io_admin_level, io_locked)

    def get_rrs2_motion_planner_active_during_teach_olp_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetRRS2MotionPlannerActiveDuringTeachOLPInfo(CATBSTR
                | ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the
                |     "RRS2MotionPlannerActiveDuringTeachOLP" parameter.
                |     Role:Retrieves the state of the "RRS2MotionPlannerActiveDuringTeachOLP"
                |     parameter in the current environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.rrs_setting_att.GetRRS2MotionPlannerActiveDuringTeachOLPInfo(io_admin_level, io_locked)

    def get_rrs2_sim_run_downloaders_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetRRS2SimRunDownloadersInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the "RRS2SimRunDownloaders"
                |     parameter.
                |     Role:Retrieves the state of the "RRS2SimRunDownloaders" parameter in the
                |     current environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.rrs_setting_att.GetRRS2SimRunDownloadersInfo(io_admin_level, io_locked)

    def get_rrs2_stop_vrc_when_sim_stops_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetRRS2StopVRCWhenSimStopsInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the "RRS2StopVRCWhenSimStops"
                |     parameter.
                |     Role:Retrieves the state of the "RRS2StopVRCWhenSimStops" parameter in the
                |     current environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.rrs_setting_att.GetRRS2StopVRCWhenSimStopsInfo(io_admin_level, io_locked)

    def get_rrs2_update_program_on_download_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetRRS2UpdateProgramOnDownloadInfo(CATBSTR
                | ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the "RRS2UpdateProgramOnDownload"
                |     parameter.
                |     Role:Retrieves the state of the "RRS2UpdateProgramOnDownload" parameter in
                |     the current environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.rrs_setting_att.GetRRS2UpdateProgramOnDownloadInfo(io_admin_level, io_locked)

    def get_rrs2_use_vrc_inverse_kinematics_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetRRS2UseVRCInverseKinematicsInfo(CATBSTR
                | ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the "RRS2UseVRCInverseKinematics"
                |     parameter.
                |     Role:Retrieves the state of the "RRS2UseVRCInverseKinematics" parameter in
                |     the current environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.rrs_setting_att.GetRRS2UseVRCInverseKinematicsInfo(io_admin_level, io_locked)

    def get_rrs2_use_vrc_turn_limits_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetRRS2UseVRCTurnLimitsInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the "RRS2UseVRCTurnLimits"
                |     parameter.
                |     Role:Retrieves the state of the "RRS2UseVRCTurnLimits" parameter in the
                |     current environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.rrs_setting_att.GetRRS2UseVRCTurnLimitsInfo(io_admin_level, io_locked)

    def get_rrs_lib_dir_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetRRSLibDirInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the "RRS$LIB"
                |     parameter.
                |     Role:Retrieves the state of the "RRS$LIB" parameter in the current
                |     environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.rrs_setting_att.GetRRSLibDirInfo(io_admin_level, io_locked)

    def get_rrs_server_file_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetRRSServerFileInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the "RRS Servers File"
                |     parameter.
                |     Role:Retrieves the state of the "RRS Servers File" parameter in the current
                |     environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.rrs_setting_att.GetRRSServerFileInfo(io_admin_level, io_locked)

    def set_rcs_data_lib_dir_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetRCSDataLibDirLock(boolean iLocked)
                | 
                |     Locks or unlocks the "RCSDATA$LIB" parameter.
                |     Role: Locks or unlocks the "RCSDATA$LIB" parameter if the operation is
                |     allowed in the current administrated environment. In user mode this method will
                |     always return E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             1 : to lock the parameter.
                |             0 : to unlock the parameter. 
                | 
                |     Returns:
                |         Legal values:
                |         S_OK : on Success
                |         E_FAIL: on Failure

        :param bool i_locked:
        :rtype: None
        """
        return self.rrs_setting_att.SetRCSDataLibDirLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_rcs_data_lib_dir_lock'
        # # vba_code = """
        # # Public Function set_rcs_data_lib_dir_lock(rrs_setting_att)
        # #     Dim iLocked (2)
        # #     rrs_setting_att.SetRCSDataLibDirLock iLocked
        # #     set_rcs_data_lib_dir_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_rrs2_connect_downloaders_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetRRS2ConnectDownloadersLock(boolean iLocked)
                | 
                |     Locks or unlocks the "RRS2ConnectDownloaders" parameter.
                |     Role: Locks or unlocks the "RRS2ConnectDownloaders" parameter if the
                |     operation is allowed in the current administrated environment. In user mode
                |     this method will always return E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             1 : to lock the parameter.
                |             0 : to unlock the parameter. 
                | 
                |     Returns:
                |         Legal values:
                |         S_OK : on Success
                |         E_FAIL: on Failure

        :param bool i_locked:
        :rtype: None
        """
        return self.rrs_setting_att.SetRRS2ConnectDownloadersLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_rrs2_connect_downloaders_lock'
        # # vba_code = """
        # # Public Function set_rrs2_connect_downloaders_lock(rrs_setting_att)
        # #     Dim iLocked (2)
        # #     rrs_setting_att.SetRRS2ConnectDownloadersLock iLocked
        # #     set_rrs2_connect_downloaders_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_rrs2_consistency_cmd_downloaders_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetRRS2ConsistencyCmdDownloadersLock(boolean iLocked)
                | 
                |     Locks or unlocks the "RRS2ConsistencyCmdDownloaders"
                |     parameter.
                |     Role: Locks or unlocks the "RRS2ConsistencyCmdDownloaders" parameter if the
                |     operation is allowed in the current administrated environment. In user mode
                |     this method will always return E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             1 : to lock the parameter.
                |             0 : to unlock the parameter. 
                | 
                |     Returns:
                |         Legal values:
                |         S_OK : on Success
                |         E_FAIL: on Failure

        :param bool i_locked:
        :rtype: None
        """
        return self.rrs_setting_att.SetRRS2ConsistencyCmdDownloadersLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_rrs2_consistency_cmd_downloaders_lock'
        # # vba_code = """
        # # Public Function set_rrs2_consistency_cmd_downloaders_lock(rrs_setting_att)
        # #     Dim iLocked (2)
        # #     rrs_setting_att.SetRRS2ConsistencyCmdDownloadersLock iLocked
        # #     set_rrs2_consistency_cmd_downloaders_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_rrs2_controller_identifiers_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetRRS2ControllerIdentifiersLock(boolean iLocked)
                | 
                |     Locks or unlocks the "RRS2ControllerIdentifiers"
                |     parameter.
                |     Role: Locks or unlocks the "RRS2ControllerIdentifiers" parameter if the
                |     operation is allowed in the current administrated environment. In user mode
                |     this method will always return E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             1 : to lock the parameter.
                |             0 : to unlock the parameter. 
                | 
                |     Returns:
                |         Legal values:
                |         S_OK : on Success
                |         E_FAIL: on Failure

        :param bool i_locked:
        :rtype: None
        """
        return self.rrs_setting_att.SetRRS2ControllerIdentifiersLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_rrs2_controller_identifiers_lock'
        # # vba_code = """
        # # Public Function set_rrs2_controller_identifiers_lock(rrs_setting_att)
        # #     Dim iLocked (2)
        # #     rrs_setting_att.SetRRS2ControllerIdentifiersLock iLocked
        # #     set_rrs2_controller_identifiers_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_rrs2_delete_auto_download_files_after_xfer_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetRRS2DeleteAutoDownloadFilesAfterXferLock(boolean
                | iLocked)
                | 
                |     Locks or unlocks the "RRS2DeleteAutoDownloadFilesAfterXfer"
                |     parameter.
                |     Role: Locks or unlocks the "RRS2DeleteAutoDownloadFilesAfterXfer" parameter
                |     if the operation is allowed in the current administrated environment. In user
                |     mode this method will always return E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             1 : to lock the parameter.
                |             0 : to unlock the parameter. 
                | 
                |     Returns:
                |         Legal values:
                |         S_OK : on Success
                |         E_FAIL: on Failure

        :param bool i_locked:
        :rtype: None
        """
        return self.rrs_setting_att.SetRRS2DeleteAutoDownloadFilesAfterXferLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_rrs2_delete_auto_download_files_after_xfer_lock'
        # # vba_code = """
        # # Public Function set_rrs2_delete_auto_download_files_after_xfer_lock(rrs_setting_att)
        # #     Dim iLocked (2)
        # #     rrs_setting_att.SetRRS2DeleteAutoDownloadFilesAfterXferLock iLocked
        # #     set_rrs2_delete_auto_download_files_after_xfer_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_rrs2_dflt_controller_identifier_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetRRS2DfltControllerIdentifierLock(boolean iLocked)
                | 
                |     Locks or unlocks the "RRS2DfltControllerIdentifier"
                |     parameter.
                |     Role: Locks or unlocks the "RRS2DfltControllerIdentifier" parameter if the
                |     operation is allowed in the current administrated environment. In user mode
                |     this method will always return E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             1 : to lock the parameter.
                |             0 : to unlock the parameter. 
                | 
                |     Returns:
                |         Legal values:
                |         S_OK : on Success
                |         E_FAIL: on Failure

        :param bool i_locked:
        :rtype: None
        """
        return self.rrs_setting_att.SetRRS2DfltControllerIdentifierLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_rrs2_dflt_controller_identifier_lock'
        # # vba_code = """
        # # Public Function set_rrs2_dflt_controller_identifier_lock(rrs_setting_att)
        # #     Dim iLocked (2)
        # #     rrs_setting_att.SetRRS2DfltControllerIdentifierLock iLocked
        # #     set_rrs2_dflt_controller_identifier_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_rrs2_download_during_connect_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetRRS2DownloadDuringConnectLock(boolean iLocked)
                | 
                |     Locks or unlocks the "RRS2DownloadDuringConnect"
                |     parameter.
                |     Role: Locks or unlocks the "RRS2DownloadDuringConnect" parameter if the
                |     operation is allowed in the current administrated environment. In user mode
                |     this method will always return E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             1 : to lock the parameter.
                |             0 : to unlock the parameter. 
                | 
                |     Returns:
                |         Legal values:
                |         S_OK : on Success
                |         E_FAIL: on Failure

        :param bool i_locked:
        :rtype: None
        """
        return self.rrs_setting_att.SetRRS2DownloadDuringConnectLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_rrs2_download_during_connect_lock'
        # # vba_code = """
        # # Public Function set_rrs2_download_during_connect_lock(rrs_setting_att)
        # #     Dim iLocked (2)
        # #     rrs_setting_att.SetRRS2DownloadDuringConnectLock iLocked
        # #     set_rrs2_download_during_connect_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_rrs2_download_during_sim_run_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetRRS2DownloadDuringSimRunLock(boolean iLocked)
                | 
                |     Locks or unlocks the "RRS2DownloadDuringSimRun" parameter.
                |     Role: Locks or unlocks the "RRS2DownloadDuringSimRun" parameter if the
                |     operation is allowed in the current administrated environment. In user mode
                |     this method will always return E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             1 : to lock the parameter.
                |             0 : to unlock the parameter. 
                | 
                |     Returns:
                |         Legal values:
                |         S_OK : on Success
                |         E_FAIL: on Failure

        :param bool i_locked:
        :rtype: None
        """
        return self.rrs_setting_att.SetRRS2DownloadDuringSimRunLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_rrs2_download_during_sim_run_lock'
        # # vba_code = """
        # # Public Function set_rrs2_download_during_sim_run_lock(rrs_setting_att)
        # #     Dim iLocked (2)
        # #     rrs_setting_att.SetRRS2DownloadDuringSimRunLock iLocked
        # #     set_rrs2_download_during_sim_run_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_rrs2_download_in_part_coordinates_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetRRS2DownloadInPartCoordinatesLock(boolean iLocked)
                | 
                |     Locks or unlocks the "RRS2DownloadInPartCoordinates"
                |     parameter.
                |     Role: Locks or unlocks the "RRS2DownloadInPartCoordinates" parameter if the
                |     operation is allowed in the current administrated environment. In user mode
                |     this method will always return E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             1 : to lock the parameter.
                |             0 : to unlock the parameter. 
                | 
                |     Returns:
                |         Legal values:
                |         S_OK : on Success
                |         E_FAIL: on Failure

        :param bool i_locked:
        :rtype: None
        """
        return self.rrs_setting_att.SetRRS2DownloadInPartCoordinatesLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_rrs2_download_in_part_coordinates_lock'
        # # vba_code = """
        # # Public Function set_rrs2_download_in_part_coordinates_lock(rrs_setting_att)
        # #     Dim iLocked (2)
        # #     rrs_setting_att.SetRRS2DownloadInPartCoordinatesLock iLocked
        # #     set_rrs2_download_in_part_coordinates_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_rrs2_download_log_file_name_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetRRS2DownloadLogFileNameLock(boolean iLocked)
                | 
                |     Locks or unlocks the "RRS2DownloadLogFileName" parameter.
                |     Role: Locks or unlocks the "RRS2DownloadLogFileName" parameter if the
                |     operation is allowed in the current administrated environment. In user mode
                |     this method will always return E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             1 : to lock the parameter.
                |             0 : to unlock the parameter. 
                | 
                |     Returns:
                |         Legal values:
                |         S_OK : on Success
                |         E_FAIL: on Failure

        :param bool i_locked:
        :rtype: None
        """
        return self.rrs_setting_att.SetRRS2DownloadLogFileNameLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_rrs2_download_log_file_name_lock'
        # # vba_code = """
        # # Public Function set_rrs2_download_log_file_name_lock(rrs_setting_att)
        # #     Dim iLocked (2)
        # #     rrs_setting_att.SetRRS2DownloadLogFileNameLock iLocked
        # #     set_rrs2_download_log_file_name_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_rrs2_free_play_sim_step_size_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetRRS2FreePlaySimStepSizeLock(boolean iLocked)
                | 
                |     Locks or unlocks the "RRS2FreePlaySimStepSize" parameter.
                |     Role: Locks or unlocks the "RRS2FreePlaySimStepSize" parameter if the
                |     operation is allowed in the current administrated environment. In user mode
                |     this method will always return E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             1 : to lock the parameter.
                |             0 : to unlock the parameter. 
                | 
                |     Returns:
                |         Legal values:
                |         S_OK : on Success
                |         E_FAIL: on Failure

        :param bool i_locked:
        :rtype: None
        """
        return self.rrs_setting_att.SetRRS2FreePlaySimStepSizeLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_rrs2_free_play_sim_step_size_lock'
        # # vba_code = """
        # # Public Function set_rrs2_free_play_sim_step_size_lock(rrs_setting_att)
        # #     Dim iLocked (2)
        # #     rrs_setting_att.SetRRS2FreePlaySimStepSizeLock iLocked
        # #     set_rrs2_free_play_sim_step_size_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_rrs2_main_task_processing_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetRRS2MainTaskProcessingLock(boolean iLocked)
                | 
                |     Locks or unlocks the "RRS2MainTaskProcessing" parameter.
                |     Role: Locks or unlocks the "RRS2MainTaskProcessing" parameter if the
                |     operation is allowed in the current administrated environment. In user mode
                |     this method will always return E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             1 : to lock the parameter.
                |             0 : to unlock the parameter. 
                | 
                |     Returns:
                |         Legal values:
                |         S_OK : on Success
                |         E_FAIL: on Failure

        :param bool i_locked:
        :rtype: None
        """
        return self.rrs_setting_att.SetRRS2MainTaskProcessingLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_rrs2_main_task_processing_lock'
        # # vba_code = """
        # # Public Function set_rrs2_main_task_processing_lock(rrs_setting_att)
        # #     Dim iLocked (2)
        # #     rrs_setting_att.SetRRS2MainTaskProcessingLock iLocked
        # #     set_rrs2_main_task_processing_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_rrs2_motion_planner_active_during_teach_olp_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetRRS2MotionPlannerActiveDuringTeachOLPLock(boolean
                | iLocked)
                | 
                |     Locks or unlocks the "RRS2MotionPlannerActiveDuringTeachOLP"
                |     parameter.
                |     Role: Locks or unlocks the "RRS2MotionPlannerActiveDuringTeachOLP"
                |     parameter if the operation is allowed in the current administrated environment.
                |     In user mode this method will always return E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             1 : to lock the parameter.
                |             0 : to unlock the parameter. 
                | 
                |     Returns:
                |         Legal values:
                |         S_OK : on Success
                |         E_FAIL: on Failure

        :param bool i_locked:
        :rtype: None
        """
        return self.rrs_setting_att.SetRRS2MotionPlannerActiveDuringTeachOLPLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_rrs2_motion_planner_active_during_teach_olp_lock'
        # # vba_code = """
        # # Public Function set_rrs2_motion_planner_active_during_teach_olp_lock(rrs_setting_att)
        # #     Dim iLocked (2)
        # #     rrs_setting_att.SetRRS2MotionPlannerActiveDuringTeachOLPLock iLocked
        # #     set_rrs2_motion_planner_active_during_teach_olp_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_rrs2_sim_run_downloaders_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetRRS2SimRunDownloadersLock(boolean iLocked)
                | 
                |     Locks or unlocks the "RRS2SimRunDownloaders" parameter.
                |     Role: Locks or unlocks the "RRS2SimRunDownloaders" parameter if the
                |     operation is allowed in the current administrated environment. In user mode
                |     this method will always return E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             1 : to lock the parameter.
                |             0 : to unlock the parameter. 
                | 
                |     Returns:
                |         Legal values:
                |         S_OK : on Success
                |         E_FAIL: on Failure

        :param bool i_locked:
        :rtype: None
        """
        return self.rrs_setting_att.SetRRS2SimRunDownloadersLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_rrs2_sim_run_downloaders_lock'
        # # vba_code = """
        # # Public Function set_rrs2_sim_run_downloaders_lock(rrs_setting_att)
        # #     Dim iLocked (2)
        # #     rrs_setting_att.SetRRS2SimRunDownloadersLock iLocked
        # #     set_rrs2_sim_run_downloaders_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_rrs2_stop_vrc_when_sim_stops_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetRRS2StopVRCWhenSimStopsLock(boolean iLocked)
                | 
                |     Locks or unlocks the "RRS2StopVRCWhenSimStops" parameter.
                |     Role: Locks or unlocks the "RRS2StopVRCWhenSimStops" parameter if the
                |     operation is allowed in the current administrated environment. In user mode
                |     this method will always return E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             1 : to lock the parameter.
                |             0 : to unlock the parameter. 
                | 
                |     Returns:
                |         Legal values:
                |         S_OK : on Success
                |         E_FAIL: on Failure

        :param bool i_locked:
        :rtype: None
        """
        return self.rrs_setting_att.SetRRS2StopVRCWhenSimStopsLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_rrs2_stop_vrc_when_sim_stops_lock'
        # # vba_code = """
        # # Public Function set_rrs2_stop_vrc_when_sim_stops_lock(rrs_setting_att)
        # #     Dim iLocked (2)
        # #     rrs_setting_att.SetRRS2StopVRCWhenSimStopsLock iLocked
        # #     set_rrs2_stop_vrc_when_sim_stops_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_rrs2_update_program_on_download_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetRRS2UpdateProgramOnDownloadLock(boolean iLocked)
                | 
                |     Locks or unlocks the "RRS2UpdateProgramOnDownload"
                |     parameter.
                |     Role: Locks or unlocks the "RRS2UpdateProgramOnDownload" parameter if the
                |     operation is allowed in the current administrated environment. In user mode
                |     this method will always return E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             1 : to lock the parameter.
                |             0 : to unlock the parameter. 
                | 
                |     Returns:
                |         Legal values:
                |         S_OK : on Success
                |         E_FAIL: on Failure

        :param bool i_locked:
        :rtype: None
        """
        return self.rrs_setting_att.SetRRS2UpdateProgramOnDownloadLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_rrs2_update_program_on_download_lock'
        # # vba_code = """
        # # Public Function set_rrs2_update_program_on_download_lock(rrs_setting_att)
        # #     Dim iLocked (2)
        # #     rrs_setting_att.SetRRS2UpdateProgramOnDownloadLock iLocked
        # #     set_rrs2_update_program_on_download_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_rrs2_use_vrc_inverse_kinematics_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetRRS2UseVRCInverseKinematicsLock(boolean iLocked)
                | 
                |     Locks or unlocks the "RRS2UseVRCInverseKinematics"
                |     parameter.
                |     Role: Locks or unlocks the "RRS2UseVRCInverseKinematics" parameter if the
                |     operation is allowed in the current administrated environment. In user mode
                |     this method will always return E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             1 : to lock the parameter.
                |             0 : to unlock the parameter. 
                | 
                |     Returns:
                |         Legal values:
                |         S_OK : on Success
                |         E_FAIL: on Failure

        :param bool i_locked:
        :rtype: None
        """
        return self.rrs_setting_att.SetRRS2UseVRCInverseKinematicsLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_rrs2_use_vrc_inverse_kinematics_lock'
        # # vba_code = """
        # # Public Function set_rrs2_use_vrc_inverse_kinematics_lock(rrs_setting_att)
        # #     Dim iLocked (2)
        # #     rrs_setting_att.SetRRS2UseVRCInverseKinematicsLock iLocked
        # #     set_rrs2_use_vrc_inverse_kinematics_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_rrs2_use_vrc_turn_limits_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetRRS2UseVRCTurnLimitsLock(boolean iLocked)
                | 
                |     Locks or unlocks the "RRS2UseVRCTurnLimits" parameter.
                |     Role: Locks or unlocks the "RRS2UseVRCTurnLimits" parameter if the
                |     operation is allowed in the current administrated environment. In user mode
                |     this method will always return E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             1 : to lock the parameter.
                |             0 : to unlock the parameter. 
                | 
                |     Returns:
                |         Legal values:
                |         S_OK : on Success
                |         E_FAIL: on Failure

        :param bool i_locked:
        :rtype: None
        """
        return self.rrs_setting_att.SetRRS2UseVRCTurnLimitsLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_rrs2_use_vrc_turn_limits_lock'
        # # vba_code = """
        # # Public Function set_rrs2_use_vrc_turn_limits_lock(rrs_setting_att)
        # #     Dim iLocked (2)
        # #     rrs_setting_att.SetRRS2UseVRCTurnLimitsLock iLocked
        # #     set_rrs2_use_vrc_turn_limits_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_rrs_lib_dir_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetRRSLibDirLock(boolean iLocked)
                | 
                |     Locks or unlocks the "RRS$LIB" parameter.
                |     Role:Locks or unlocks the "RRS$LIB" parameter if it is possible in the
                |     current administrative context. In user mode this method will always return
                |     E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter.

        :param bool i_locked:
        :rtype: None
        """
        return self.rrs_setting_att.SetRRSLibDirLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_rrs_lib_dir_lock'
        # # vba_code = """
        # # Public Function set_rrs_lib_dir_lock(rrs_setting_att)
        # #     Dim iLocked (2)
        # #     rrs_setting_att.SetRRSLibDirLock iLocked
        # #     set_rrs_lib_dir_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_rrs_server_file_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetRRSServerFileLock(boolean iLocked)
                | 
                |     Sets value of "RRS Servers File" parameter.
                |     Role: Sets value of "RRS Servers File" parameter
                | 
                |     Parameters:
                | 
                |         iServerFile
                |             New value. 
                | 
                |     Returns:
                |         Legal values:
                |         S_OK : on Success
                |         E_FAIL: on Failure

        :param bool i_locked:
        :rtype: None
        """
        return self.rrs_setting_att.SetRRSServerFileLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_rrs_server_file_lock'
        # # vba_code = """
        # # Public Function set_rrs_server_file_lock(rrs_setting_att)
        # #     Dim iLocked (2)
        # #     rrs_setting_att.SetRRSServerFileLock iLocked
        # #     set_rrs_server_file_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def __repr__(self):
        return f'RRSSettingAtt(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.system_interfaces.any_object import AnyObject


class AnalysisV4Services(AnyObject):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     AnalysisV4Services
                | 
                | The interface to access a CATIAAnalysisV4Services.
                | 
                | This service provides tools to extract analysis information stored in V4 model
                | and session.
                | Note: The implementation of this API requires specific Licensing: V4A product
                | needs to be installed.
                | To get access to this service:
                | 
                |   Dim SAMV4Service As AnalysisV4Services 
                |   Set SAMV4Service = CATIA.GetItem("SAMV4Service")
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.analysis_v4_services = com_object

    def get_storage_info(self, i_model_path: str, o_prefix: str) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetStorageInfo(CATBSTR iModelPath,
                | CATBSTR oPrefix) As CATBSTR
                | 
                |     Gets V4 External Storage information stored in a model.
                | 
                |     Parameters:
                | 
                |         iModelPath:
                |             Path of model file.
                |         oExternal:
                |             Storage Path. 
                |         oPrefix:
                |             Directory prefix: Something like "D1998124T083802".
                |
                |     Example:
                | 
                |           This example return external storage information for a model
                |           path
                |
                |           Dim SAMV4Service As AnalysisV4Services 
                |           Set SAMV4Service = CATIA.GetItem("SAMV4Service")
                |           Dim Prefix As String 
                |           Prefix = ""
                |           Dim PathStorage As String 
                |           Dim sDocPath As String 
                |           sDocPath = "E:\\mymodel.model"
                |           PathStorage = SAMV4Service.GetStorageInfo(sDocPath,Prefix)
                |           CATIA.SystemService.Print "GetStorageInfo for Model: " &
                |           sDocPath
                |           CATIA.SystemService.Print "GetStorageInfo PathStorage: " &
                |           PathStorage & " Prefix " & Prefix

        :param str i_model_path:
        :param str o_prefix:
        :rtype: str
        """
        return self.analysis_v4_services.GetStorageInfo(i_model_path, o_prefix)

    def print_assembled_sets_info(self, i_session_path: str, i_print_path: str, i_submesh: int) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub PrintAssembledSetsInfo(CATBSTR iSessionPath,
                | CATBSTR iPrintPath,
                | long iSubmesh)
                | 
                |     Gets sets list for a model included in a V4 Session. The generated file
                |     contains names of load, restraint, non structural mass and displacement sets
                |     for a given submesh number.
                | 
                |     Parameters:
                | 
                |         iSessionPath:
                |             Path of session file.
                |         iPrintPath:
                |             Path where to create the dump file.
                |         iSubmesh:
                |             Submesh Number of the modelo.
                |             Note that if the file already exists it will be replaced.
                |             
                | 
                |     Example:
                | 
                |           This example extract assembled sets information.
                |
                |           Dim SAMV4Service As AnalysisV4Services 
                |           Set SAMV4Service = CATIA.GetItem("SAMV4Service")
                |           Dim sSession As String 
                |           sSession = "E:\\MYSESSION.session"
                |           Dim sSumpFile As String 
                |           sSumpFile = "E:\\MyFile.txt"
                |           SAMV4Service.PrintAssembledSetsInfo sSession,sSumpFile,120

        :param str i_session_path:
        :param str i_print_path:
        :param int i_submesh:
        :rtype: None
        """
        return self.analysis_v4_services.PrintAssembledSetsInfo(i_session_path, i_print_path, i_submesh)

    def print_coupling_analysis_info(self, i_session_path: str, i_print_path: str, i_submesh: int) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub PrintCouplingAnalysisInfo(CATBSTR iSessionPath,
                | CATBSTR iPrintPath,
                | long iSubmesh)
                | 
                |     Gets V4 Coupling analysis information.
                | 
                |     Parameters:
                | 
                |         iSessionPath:
                |             Path of the model file.
                |         iPrintPath:
                |             Path where to create the dump file.
                |         iSubmesh:
                |             Sub mesh number, the file will dump at the level of this
                |             submesh.
                |             Note that if file already exists it will be replaced.
                |
                |     Example:
                | 
                |           This example extracts sets information.
                |
                |           Dim SAMV4Service As AnalysisV4Services
                |           Set SAMV4Service = CATIA.GetItem("SAMV4Service")
                |           Dim sSession As String
                |           sSession = "E:\\MYSESSION.session"
                |           Dim sSumpFile As String
                |           sSumpFile = "E:\\MyCouplingAnalysisFile.txt"
                |           SAMV4Service.PrintCouplingAnalysisInfo sSession,sSumpFile, 120

        :param str i_session_path:
        :param str i_print_path:
        :param int i_submesh:
        :rtype: None
        """
        return self.analysis_v4_services.PrintCouplingAnalysisInfo(i_session_path, i_print_path, i_submesh)

    def print_session_info(self, i_session_path: str, i_print_path: str) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub PrintSessionInfo(CATBSTR iSessionPath,
                | CATBSTR iPrintPath)
                | 
                |     Gets V4 Session information. The file is made of submesh & model name
                |     identification.
                | 
                |     Parameters:
                | 
                |         iSessionPath:
                |             Path of session file.
                |         iPrintPath:
                |             Path where to create the dump file.
                |             Note that if the file already exists it will be replaced.
                |
                |     Example:
                |
                |           This example extract session information.
                |
                |           Dim SAMV4Service As AnalysisV4Services 
                |           Set SAMV4Service = CATIA.GetItem("SAMV4Service")
                |           Dim sSession As String 
                |           sSession = "E:\\MYSESSION.session"
                |           Dim sSumpFile As String 
                |           sSumpFile = "E:\\MyFile.txt"
                |           SAMV4Service.PrintSessionInfo sSession,sSumpFile

        :param str i_session_path:
        :param str i_print_path:
        :rtype: None
        """
        return self.analysis_v4_services.PrintSessionInfo(i_session_path, i_print_path)

    def __repr__(self):
        return f'AnalysisV4Services(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.cat_sch_platform_interfaces.sch_list_of_bst_rs import SchListOfBSTRs
from pycatia.system_interfaces.any_object import AnyObject


class SchAppCntrName(AnyObject):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     SchAppCntrName
                | 
                | Manage a schematic connector.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.sch_app_cntr_name = com_object

    def app_list_names(self) -> SchListOfBSTRs:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func AppListNames() As SchListOfBSTRs
                | 
                |     List connector names allowed.
                | 
                |     Parameters:
                | 
                |         oLConnectorNamesAllowed
                |             A list of connector names allowed. The caller must allocate memory
                |             for the first level pointer (i.e. oLConnectorNamesAllowed) and release the
                |             second level pointer (i.e. \\*oLConnectorNamesAllowed) after usage.
                |
                |     Example:
                |
                |          Dim objThisIntf As SchAppCntrName
                |          Dim objArg1 As SchListOfBSTRs
                |           ...
                |          Set objArg1 = objThisIntf.AppListNames

        :rtype: SchListOfBSTRs
        """
        return SchListOfBSTRs(self.sch_app_cntr_name.AppListNames())

    def get_name(self, o_name: str) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub GetName(CATBSTR oName)
                | 
                |     Get the application connector name.
                | 
                |     Parameters:
                | 
                |         oName
                |             The connector name. The caller must allocate memory for the first
                |             level pointer (i.e. oName) and release the second level pointer (i.e. \\*oName)
                |             after usage. 
                | 
                |     Example:
                |
                |          Dim objThisIntf As SchAppCntrName
                |          Dim strVar1 As String
                |           ...
                |          objThisIntf.GetNamestrVar1

        :param str o_name:
        :rtype: None
        """
        return self.sch_app_cntr_name.GetName(o_name)

    def set_name(self, i_name: str) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetName(CATBSTR iName)
                | 
                |     Set the application connector name.
                | 
                |     Parameters:
                | 
                |         oName
                |             The connector name. 
                | 
                |     Example:
                | 
                |           
                | 
                |          Dim objThisIntf As SchAppCntrName
                |          Dim strVar1 As String
                |           ...
                |          objThisIntf.SetNamestrVar1

        :param str i_name:
        :rtype: None
        """
        return self.sch_app_cntr_name.SetName(i_name)

    def __repr__(self):
        return f'SchAppCntrName(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.product_structure_interfaces.product import Product
from pycatia.system_interfaces.any_object import AnyObject


class FastenerGroup(AnyObject):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     FastenerGroup

    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.fastener_group = com_object

    @property
    def colour(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property Color(long iColor) (Write Only)
                | 
                |     Sets the color of the fasteners.
                | 
                |     Example:
                |         This example sets the Color type of all the fasteners to
                |         red
                | 
                |          redCol  =16711680 'Encoded RGB color within long integer (R=255 G=0
                |          B=0)
                |          MyFastenerGroup.Color = redCol

        :rtype: int
        """

        return self.fastener_group.Color

    @colour.setter
    def colour(self, value: int):
        """
        :param int value:
        """

        self.fastener_group.Color = value

    @property
    def style(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property Style(CATBSTR iStyle) (Write Only)
                | 
                |     Sets the CGR Style representation for the Spot Welds in the 3D
                |     Viewer.
                | 
                |     Parameters:
                | 
                |         iStyleType
                |             of the CGR Style to be used for representation.
                |             The valid set of Styles are :-
                | 
                |                 As specified in XML in tools-options page
                | 
                |             Example:
                |                 This example sets the CGR Style type of all the fasteners to
                |                 Sphere provided it is available in XML file
                | 
                |                  MyFastenerGroup.Style = "Sphere"

        :rtype: str
        """

        return self.fastener_group.Style

    @style.setter
    def style(self, value: str):
        """
        :param str value:
        """

        self.fastener_group.Style = value

    @property
    def symbol(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property Symbol(CATBSTR iColor) (Write Only)
                | 
                |     Sets the symbol for representation for the Spot Welds in the 3D
                |     Viewer.
                | 
                |     Parameters:
                | 
                |         iSymbolType
                |             of the symbol to be used for representation.
                |             The valid set of symbols are :-
                | 
                |                 CROSS
                |                 PLUS
                |                 CONCENTRIC
                |                 COINCIDENT
                |                 FULLCIRCLE
                |                 FULLSQUARE
                |                 STAR
                |                 DOT
                |                 SMALLDOT
                | 
                |             Example:
                |                 This example sets the Symbol type of all the fasteners to
                |                 FULLSquare
                | 
                |                  MyFastenerGroup.Symbol = "FULLSQUARE"

        :rtype: str
        """

        return self.fastener_group.Symbol

    @symbol.setter
    def symbol(self, value: str):
        """
        :param str value:
        """

        self.fastener_group.Symbol = value

    def get_count(self, id_name: str) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetCount(CATBSTR IDName) As long
                | 
                |     Returns the number of entities in the fastener group of the
                |     Type.
                | 
                |     Parameters:
                | 
                |         oNumOfEntities
                |             The number of Entities 
                | 
                |     Example:
                |         This example gets number of welds in the fastener
                |         Group
                | 
                |          Dim NumberOfWelds
                |          NumberOfWelds = MyFastenerGroup.GetCount("DELMIASpotWeld")
                |          
                | 
                |         This example gets number of FastenerGroups in the fastener
                |         Group
                | 
                |          Dim NumberOfGroups
                |          NumberOfGroups = MyFastenerGroup.GetCount("DELMIAFastenerGroup")

        :param str id_name:
        :rtype: int
        """
        return self.fastener_group.GetCount(id_name)

    def get_items(self, id_name: str, o_list_of_entities: tuple) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub GetItems(CATBSTR IDName,
                | CATSafeArrayVariant oListOfEntities)
                | 
                |     Returns the entities in the fastener group of the type which is input.
                |     which are direct children only 
                | 
                | Example:
                |     This example gets welds in the fastener Group
                | 
                |      Dim NumberOfWelds
                |      NumberOfWelds = MyFastenerGroup.GetItems("DELMIASpotWeld")
                |      
                | 
                |     This example gets the FastenerGroups in the fastener Group
                | 
                |      Dim NumberOfGroups
                |      NumberOfGroups = MyFastenerGroup.GetItems("DELMIAFastenerGroup")

        :param str id_name:
        :param tuple o_list_of_entities:
        :rtype: None
        """
        return self.fastener_group.GetItems(id_name, o_list_of_entities)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'get_items'
        # # vba_code = """
        # # Public Function get_items(fastener_group)
        # #     Dim IDName (2)
        # #     fastener_group.GetItems IDName
        # #     get_items = IDName
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def get_joined_part_names(self, o_list_of_parts: tuple) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub GetJoinedPartNames(CATSafeArrayVariant oListOfParts)
                | 
                |     Returns the list of part names joined by fastener.
                | 
                |     Parameters:
                | 
                |         oListOfParts
                |             The list of parts 
                | 
                |     Example:
                |         This example gets list of parts joined by fastener
                | 
                |          Dim NumberOfParts
                |          Dim JoiningParts()
                |          NumberOfParts = MyFastenerGroup.NumberOfJoiningParts
                |          ReDim JoiningParts(NumParts-1)
                |          MyFastenerGroup.GetJoinedPartNames(JoiningParts)

        :param tuple o_list_of_parts:
        :rtype: None
        """
        return self.fastener_group.GetJoinedPartNames(o_list_of_parts)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'get_joined_part_names'
        # # vba_code = """
        # # Public Function get_joined_part_names(fastener_group)
        # #     Dim oListOfParts (2)
        # #     fastener_group.GetJoinedPartNames oListOfParts
        # #     get_joined_part_names = oListOfParts
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def get_part(self, index: int) -> Product:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetPart(short index) As Product
                | 
                |     Returns the product at the specified index from the list of parts joined by
                |     fastener group.
                | 
                |     Parameters:
                | 
                |         index
                |             Index should be greater than equal to 1. 
                | 
                |     Example:
                |         This example gets the part at index 1
                | 
                |          Dim MyProduct As Product
                |          Set MyProduct = MyFastenerGroup.GetPart(1)

        :param int index:
        :rtype: Product
        """
        return Product(self.fastener_group.GetPart(index))

    def hide(self) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub Hide()
                | 
                |     Hides all the entities in the fastener group. 
                | 
                | Example:
                |     This example hides all the welds in the fastener Group
                | 
                |      MyFastenerGroup.Hide

        :rtype: None
        """
        return self.fastener_group.Hide()

    def number_of_joining_parts(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func NumberOfJoiningParts() As long
                | 
                |     Returns the number of parts joined by the fastener group.
                | 
                |     Parameters:
                | 
                |         oNumOfParts
                |             The number of parts 
                | 
                |     Example:
                |         This example gets number of parts joined by fastener
                | 
                |          Dim NumberOfParts
                |          NumberOfParts = MyFastenerGroup.NumberOfJoiningParts

        :rtype: int
        """
        return self.fastener_group.NumberOfJoiningParts()

    def show(self) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub Show()
                | 
                |     Shows all the entities in the fastener group. 
                | 
                | Example:
                |     This example shows all the welds in the fastener Group
                | 
                |      MyFastenerGroup.Show

        :rtype: None
        """
        return self.fastener_group.Show()

    def __repr__(self):
        return f'FastenerGroup(name="{self.name}")'
